<?php
/**
 * @package			No Boss Extensions
 * @subpackage  	No Boss Banners
 * @author			No Boss Technology <contact@nobosstechnology.com>
 * @copyright		Copyright (C) 2018 No Boss Technology. All rights reserved.
 * @license			GNU Lesser General Public License version 3 or later; see <https://www.gnu.org/licenses/lgpl-3.0.en.html>
 */

defined('_JEXEC') or die;

jimport('joomla.filesystem.folder');

// Carrega helper do módulo.
JLoader::register('ModNobossbannersHelper', __DIR__ . '/helper.php');

// Verifica se no boss library esta instalada: se ainda nao estiver, tenta instalar e se ainda nao der retorna false
if(!ModNobossbannersHelper::checkLibraryInstallation()){
    return;
}

// Bibliotecas a importar
jimport('noboss.util.url');
jimport('noboss.util.fonts');
jimport('noboss.util.loadextensionassets');

$app = JFactory::getApplication();
$menu = $app->getMenu();
$active = $menu->getActive();

// pega o template vinculado a pagina
$tmpl = $app->getTemplate(true);
// pega os parametros do template
$tmplParams = $tmpl->params;
// pega a cor primaria setada nos parametros do template
$tmplPrimaryColor = $tmplParams->get('primary_color');
// pega a cor secundaria setada nos parametros do template
$tmplSecondaryColor = $tmplParams->get('secondary_color');

// Parametro com nome do modulo nao esta definido
if (!isset($module->name)){
    $module->name = str_replace('mod_', '', $module->module);
}
$moduleName = $module->name;
$extensionName = "mod_" . $module->name;

// Instancia objeto da classe para obter o diretorio da extensao
$assetsObject = new NoBossUtilLoadExtensionAssets("lib_noboss");
// Obtem diretorio da extensao
$extensionPath = $assetsObject->getDirectoryExtension(false);
// Carrega arquivo traducao para extensao especificada
JFactory::getLanguage()->load("lib_noboss", $extensionPath);
// Documento do joomla
$doc = JFactory::getDocument();
$ds = DIRECTORY_SEPARATOR;

// variável que armazena o tema escolhido 
$theme = json_decode($params->get("theme"))->theme;

// Obtem banners cadastrados
$banners = (array) $params->get($theme);

if($theme == "model3"){
    // string com o nome da modal de itens concatenado com o modelo selecionado 
    $itemsCustomizationXml = $theme . '_items_customization';
    // variável que armazena o objeto com os parâmetros da modal de itens do tema selecionado  
    $itemsCustomization = json_decode($params->get($itemsCustomizationXml));
    // Parametrizações para o plugin de slider 
    $jsConfig = new StdClass();
    $jsConfig->autoPlay = $itemsCustomization->enable_auto_play ? true : false;
    $jsConfig->interval = $itemsCustomization->enable_auto_play ? $itemsCustomization->auto_play_interval : 5;
    $jsConfig->dragging = $itemsCustomization->enable_dragging ? true : false;
    $jsConfig->showDots = $itemsCustomization->show_dots ? true : false;

    // verifica qual o modo de exibição
    // 1: é manual, então exibe container
    // 0: é full width 
    if(isset($itemsCustomization->content_display_mode) && $itemsCustomization->content_display_mode){
        $itemColumns = !empty($itemsCustomization->content_columns) ? "nb-lg-{$itemsCustomization->content_columns} nb-md-{$itemsCustomization->content_columns} nb-sm-{$itemsCustomization->content_columns} nb-xs-{$itemsCustomization->content_columns}" : "";
    }

    // Dots
    $showDots = $jsConfig->showDots;
    $dotsStyle = "";
    // pega a cor definida no modulo ou a cor primaria do template
    $itemsCustomization->dots_color = !empty($itemsCustomization->dots_color) ? $itemsCustomization->dots_color : $tmplPrimaryColor; 
    $dotsStyle .= "background-color: " . $itemsCustomization->dots_color . "; ";
    $dotsStyle .= "padding: " . implode(' ', $itemsCustomization->dots_size) . "; ";
    $dotsStyle .= "margin: 0 " . $itemsCustomization->dots_spacing_items . "px; ";

    $dotsShowBorder = $itemsCustomization->show_dots_border;
    $dotsStyle .= $dotsShowBorder ? "border: 2px solid " . $itemsCustomization->dots_border_color . "; " : "";
    $dotsStyle .= "border-radius: {$itemsCustomization->dots_border_radius_size}px; ";
    
    $dotsActiveStyle = "";
    $itemsCustomization->dots_active_color = !empty($itemsCustomization->dots_active_color) ? $itemsCustomization->dots_active_color : $tmplSecondaryColor;
    $dotsActiveStyle .= "background-color:  " . $itemsCustomization->dots_active_color . "; ";
    $dotsActiveStyle .= "padding: " . implode(' ', $itemsCustomization->dots_active_size) . "; ";
    
    // Setas
    $arrowsStyle = "font-size: inherit; ";
    $arrowsStyleHover = "";
    $showArrows = $itemsCustomization->show_arrows != 'none';
    if($showArrows){
        $arrowsIcon = $itemsCustomization->arrows_icon;
        $arrowsIconSize = $itemsCustomization->arrows_icon_size;
        if(!empty($arrowsIconSize)){
            $arrowsIconSizeEm = $arrowsIconSize/16;
            $arrowsIconSize = "font-size: {$arrowsIconSize}px; font-size: {$arrowsIconSizeEm}em;";
        }
        $arrowsStyle .= "padding: " . implode(' ', $itemsCustomization->arrows_spacing) . ";";
        if ($itemsCustomization->show_arrows_border_radius && !empty($itemsCustomization->arrows_border_radius)){
            $arrowsStyle .= 'border-radius:' . $itemsCustomization->arrows_border_radius . 'px;';
        }
        if ($itemsCustomization->show_arrows_background && !empty($itemsCustomization->arrows_background)){
            // pega a cor definida no modulo ou a cor primaria do template
            $itemsCustomization->arrows_background = !empty($itemsCustomization->arrows_background) ? $itemsCustomization->arrows_background : $tmplPrimaryColor;
            $arrowsStyle .= 'background-color:' . $itemsCustomization->arrows_background . '; ';
            // pega a cor definida no modulo ou a cor secundaria do template
            $itemsCustomization->arrows_background_hover = !empty($itemsCustomization->arrows_background_hover) ? $itemsCustomization->arrows_background_hover : $tmplSecondaryColor;
            $arrowsStyleHover .= 'background-color:' . $itemsCustomization->arrows_background_hover . ' !important; ';
        }
        if ($itemsCustomization->show_arrows_border && !empty($itemsCustomization->arrows_border_color)){
            $arrowsStyle .= 'border: 1px solid ' . $itemsCustomization->arrows_border_color . ';';
        }
        if (!empty($itemsCustomization->arrows_color)){
            // pega a cor definida no modulo ou a cor primaria do template
            $itemsCustomization->arrows_color = !empty($itemsCustomization->arrows_color) ? $itemsCustomization->arrows_color : $tmplPrimaryColor;
            $arrowsStyle .= ' color:' . $itemsCustomization->arrows_color . ';';
        }

        $arrowsStyleMobile = "";
        if(isset($itemsCustomization->arrows_icon_size_mobile)){
            $arrowIconSizeMobile = $itemsCustomization->arrows_icon_size_mobile;
            $arrowIconSizeMobileEm = $arrowIconSizeMobile/16;
            $arrowsStyleMobile =  "font-size: {$arrowIconSizeMobile}px; font-size: {$arrowIconSizeMobileEm}em !important;";
        }
    }
    $height = $itemsCustomization->height . 'px';
    $heightMobile = 'height: ' . $itemsCustomization->height_mobile . 'px !important;';
}


$nowDate = date('Y-m-d H:i:s');
// string com o nome da modal de estilo customizado do item concatenado com o modelo selecionado 
$itemCustomizationXml = $theme . '_subform_item_customization';

// Verifica se foi cadastrado ao menos um
if (count($banners) > 0){
    
    // Percorre todos os banners
    foreach ($banners as $key => &$bannerItem) {
        
        if($theme == "model3"){
            // Não está publicado o bannerItem
            if ($bannerItem->published != 1){
                unset($banners[$key]);
                continue;
            }
            // Data de publicacao de inicio esta definida e eh maior do que a data atual
            else if ((($bannerItem->publish_in != '') && ($bannerItem->publish_in != '0000-00-00 00:00:00')) &&
            (strtotime($bannerItem->publish_in) >= strtotime($nowDate))){
                unset($banners[$key]);
                continue;
            }
            // Data de publicacao de fim esta definida e eh menor do que a data atual
            else if ((($bannerItem->publish_down != '') && ($bannerItem->publish_down != '0000-00-00 00:00:00')) &&
            (strtotime($nowDate) >= strtotime($bannerItem->publish_down))){
                unset($banners[$key]);
                continue;
            }
        }
        
        // variável que armazena o objeto com os parâmetros da modal de estilo customizado do item   
        $itemCustomization = json_decode($bannerItem->$itemCustomizationXml);
        $bannerItem->item_customization = json_decode($bannerItem->$itemCustomizationXml);
        
        $bannerItem->item_customization->content_position = !empty($bannerItem->item_customization->text_box_horizontal_position) ? "nb-horizontal--{$bannerItem->item_customization->text_box_horizontal_position} " : "";
        $bannerItem->item_customization->content_position .= !empty($bannerItem->item_customization->text_box_vertical_position) ? "nb-vertical--{$bannerItem->item_customization->text_box_vertical_position} " : "";
        $bannerItem->item_customization->content_position .= !empty($bannerItem->item_customization->text_box_horizontal_position_mobile) ? "nb-horizontal-mobile--{$bannerItem->item_customization->text_box_horizontal_position_mobile} " : "";
        $bannerItem->item_customization->content_position .= !empty($bannerItem->item_customization->text_box_vertical_position_mobile) ? "nb-vertical-mobile--{$bannerItem->item_customization->text_box_vertical_position_mobile} " : "";
        
        //
        // Dados para estilo do título
        $bannerItem->title_style = "";
        $bannerItem->title_style .= !empty($itemCustomization->title_font) ? NoBossUtilFonts::importNobossfontlist($itemCustomization->title_font) : "";
        $bannerItem->title_style .= !empty($itemCustomization->title_transform) ? " text-transform: " . $itemCustomization->title_transform . ";" : "";
        $bannerItem->title_style .= !empty($itemCustomization->title_space) ? ' padding: ' . implode(' ', $itemCustomization->title_space) . '; ' : '';
        $itemTitleSize = !empty($itemCustomization->title_size) ? $itemCustomization->title_size : "";
        $itemTitleSizeMobile = !empty($itemCustomization->title_size_mobile) ? $itemCustomization->title_size_mobile : "";
        $bannerItem->title_style_mobile = "";
        if(!empty($itemTitleSize)){
            $itemTitleSizeEm = $itemTitleSize/16;
            $bannerItem->title_style .= " font-size: {$itemTitleSize}px; font-size: {$itemTitleSizeEm}em;";
        }
        if(!empty($itemTitleSizeMobile)){
            $itemTitleSizeMobileEm = $itemTitleSizeMobile/16;
            $bannerItem->title_style_mobile .= " font-size: {$itemTitleSizeMobile}px; font-size: {$itemTitleSizeMobileEm}em !important;";
        }
        //
        // Dados para texto de apoio do banner 
        $bannerItem->subtitle_style = "";
        $bannerItem->subtitle_style .= NoBossUtilFonts::importNobossfontlist($itemCustomization->subtitle_font);
        $bannerItem->subtitle_style .= " text-transform: " . $itemCustomization->subtitle_transform . ";";
        $bannerItem->subtitle_style .= !empty($itemCustomization->subtitle_space) ? ' padding: ' . implode(' ', $itemCustomization->subtitle_space) . '; ' : '';
        $itemSubtitleSize = $itemCustomization->subtitle_size;
        $itemSubtitleSizeMobile = $itemCustomization->subtitle_size_mobile;
        $bannerItem->subtitle_style_mobile = "";
        if(!empty($itemSubtitleSize)){
            $itemSubtitleSizeEm = $itemSubtitleSize/16;
            $bannerItem->subtitle_style .= " font-size: {$itemSubtitleSize}px; font-size: {$itemSubtitleSizeEm}em;";
        }
        if(!empty($itemSubtitleSizeMobile)){
            $itemSubtitleSizeMobileEm = $itemSubtitleSizeMobile/16;
            $bannerItem->subtitle_style_mobile .= " font-size: {$itemSubtitleSizeMobile}px; font-size: {$itemSubtitleSizeMobileEm}em !important;";
        }

        $bannerItem->background_style = "";
        // Valida se foi selecionada a opção de exibir filtro
        if($itemCustomization->image_filter){
            // Valida se a opção de filtro selecionada foi 'transparent'
            if($itemCustomization->image_filter == "transparent"){
                $transparentFilter = $itemCustomization->image_transparent_filter;
                $bannerItem->filter = "background-color: {$transparentFilter};";
            }else{
                // senão, o tipo é gradiente
                $gradient1 = $itemCustomization->image_gradient_filter_1;
                $gradient2 = $itemCustomization->image_gradient_filter_2;
                $bannerItem->filter = "background: -webkit-linear-gradient(right, {$gradient1} 0%,{$gradient2} 100%);";
                $bannerItem->filter .= " background: linear-gradient(right, {$gradient1} 0%,{$gradient2} 100%);";
            }
        }
        if($theme == "model1"){
            // Verifica se foi selecionado para exibir imagem e monta o estilo considerando o modelo de banner com imagem 
            if($bannerItem->show_image && $bannerItem->image != ''){
                $bannerItem->background_style = "height: 100vh; background-size: cover; position: relative; background-position: center; background-image: url('" . $bannerItem->image . "');";
            }else{
                // pega a cor definida no modulo ou a cor primaria do template
                $bannerItem->background_color = !empty($bannerItem->background_color) ? $bannerItem->background_color : $tmplPrimaryColor;
                // Caso não tenha sido setada a opção de banner com imagem, é montado o estilo com fundo colorido
                $bannerItem->background_style = "height: 100vh; position: relative; background-color: {$bannerItem->background_color};>";
            }
        }
        // verifica se o modelo é o model2 para pegar a altura do desktop e setar o formato do link como botão pois só tem esta opção neste modelo
        if($theme == "model2"){
            $bannerItem->height = 'height: ' . $bannerItem->item_customization->height . 'px;';
        }
        // Verifica se o modelo selecionado não é o model3, ou seja, se é o model1 ou model2 
        if($theme != "model3"){
            // Verifica se foi informada a altura do banner para o mobile e monta o estilo necessário
            if(!empty($bannerItem->item_customization->height_mobile)){
                $bannerItem->height_mobile = 'height: ' . $bannerItem->item_customization->height_mobile . 'px !important;';
            }

            // verifica qual o modo de exibição
            // 1: é manual, então exibe container
            // 0: é full width 
            if(isset($bannerItem->item_customization->content_display_mode) && $bannerItem->item_customization->content_display_mode){
                $itemColumns = !empty($bannerItem->item_customization->content_columns) ? "nb-lg-{$bannerItem->item_customization->content_columns} nb-md-{$bannerItem->item_customization->content_columns} nb-sm-{$bannerItem->item_customization->content_columns} nb-xs-{$bannerItem->item_customization->content_columns}" : "";
            }
        }else{
            // Verifica se foi selecionado para exibir imagem e monta o estilo considerando o modelo de banner com imagem 
            if($bannerItem->show_image && $bannerItem->image != ''){
                $bannerItem->background_style = "height: {$height}; background-size: cover; position: relative; background-position: center; background-image: url('" . $bannerItem->image . "');";
            }else{
                // pega a cor definida no modulo ou a cor primaria do template
                $bannerItem->background_color = !empty($bannerItem->background_color) ? $bannerItem->background_color : $tmplPrimaryColor;
                // Caso não tenha sido setada a opção de banner com imagem, é montado o estilo com fundo colorido
                $bannerItem->background_style = "height: {$height}; position: relative; background-color: {$bannerItem->background_color};>";
            }
        }
        
        // Valida se foi cadastrada uma imagem pro mobile
        if(!empty($bannerItem->image_mobile)){
            if (filter_var($bannerItem->image_mobile, FILTER_VALIDATE_URL)) { 
                $bannerItem->image_mobile = "background-image: url('" . $bannerItem->image_mobile . "') !important;";
            }else{
                $bannerItem->image_mobile = "background-image: url('" . JURI::root() . $bannerItem->image_mobile . "') !important;";
            }
        }
        $bannerItem->item_customization->overlay_position = "";
        
        // Monta o estilo da altura da imagem overlay 
        if($bannerItem->item_customization->show_image_overlay){
            $bannerItem->overlay_image_height = "height: " . $bannerItem->item_customization->overlay_image_height . "px;";
            $bannerItem->overlay_image_height_mobile = "height: " . $bannerItem->item_customization->overlay_image_height_mobile . "px;";
            $bannerItem->item_customization->overlay_position = "nb-horizontal--{$bannerItem->item_customization->overlay_image_horizontal_position} nb-vertical--{$bannerItem->item_customization->overlay_image_vertical_position} nb-horizontal-mobile--{$bannerItem->item_customization->overlay_image_horizontal_position_mobile} nb-vertical-mobile--{$bannerItem->item_customization->overlay_image_vertical_position_mobile}";
        }
        
        $bannerItem->links = new \stdClass();
        if($bannerItem->show_link){
            $bannerItem->links->link1 = json_decode($bannerItem->link1_customization);
        }
        
        if($bannerItem->show_link == 'button' && $bannerItem->show_link2){
            $bannerItem->links->link2 = json_decode($bannerItem->link2_customization);
        }
        $count = 0;
        $bannerItem->links_class = "";
        foreach ($bannerItem->links as $key => $link) {
            $count++;
            // Valida se o tipo de link é externo 
            if($link->link_option == "external") {
                $link->link_url = $link->link_external;
            // Valida se o tipo de link é interno, ou seja, um item de menu 
            } else if($link->link_option == "internal") {
                $link->link_url = NoBossUtilUrl::getUrlItemMenu($link->link_internal);
            }
            $link->link_target = $link->link_target ? "_blank" : "_self";
            if($bannerItem->show_link == 'button'){
                // se link deve ser exibido como botão 
                // armazena o estilo do botão 
                $link->button_style = "";
                // armazena o estilo do botão para o hover
                $link->button_style_hover = "";
                // pega a cor definida no modulo ou a cor primaria do template
                $link->buttons_text_color = !empty($link->buttons_text_color) ? $link->buttons_text_color : $tmplPrimaryColor;
                // pega a cor definida no modulo ou a cor primaria do template
                $link->buttons_background_color = !empty($link->buttons_background_color) ? $link->buttons_background_color : $tmplPrimaryColor;
                // pega a cor definida no modulo ou a cor primaria do template
                $link->buttons_border_color = !empty($link->buttons_border_color) ? $link->buttons_border_color : $tmplPrimaryColor;
                // pega a cor definida no modulo ou a cor secundaria do template
                $link->buttons_hover_text_color = !empty($link->buttons_hover_text_color) ? $link->buttons_hover_text_color : $tmplSecondaryColor;
                // pega a cor definida no modulo ou a cor secundaria do template
                $link->buttons_background_hover_color = !empty($link->buttons_background_hover_color) ? $link->buttons_background_hover_color : $tmplSecondaryColor;
                // pega a cor definida no modulo ou a cor secundaria do template
                $link->buttons_hover_border_color = !empty($link->buttons_hover_border_color) ? $link->buttons_hover_border_color : $tmplSecondaryColor;
                // Verifica tipo de link entre as opções abaixo e retorna o estilo para ser colocado no link na tmpl
                switch ($link->buttons_style) {
                    // Botão quadrado
                    case 'squared-button':
                        $link->button_style = "color: {$link->buttons_text_color}; background-color: {$link->buttons_background_color};";
                        $link->button_style_hover = "color: {$link->buttons_hover_text_color} !important; background-color: {$link->buttons_background_hover_color} !important;";
                        break;
                    // Botão arredondado
                    case 'rounded-button':
                        $link->button_style = "color: {$link->buttons_text_color}; background-color: {$link->buttons_background_color}; border-radius: {$link->buttons_border_radius_size}px;";
                        $link->button_style_hover = "color: {$link->buttons_hover_text_color} !important; background-color: {$link->buttons_background_hover_color} !important;";
                        break;
                    // Botão transparente quadrado
                    case 'ghost-squared-button':
                        $link->button_style = "background-color: transparent; border: 2px solid; color: {$link->buttons_text_color}; border-color: {$link->buttons_border_color};";
                        $link->button_style_hover = "color: {$link->buttons_hover_text_color} !important; border-color: {$link->buttons_hover_border_color} !important; background-color: {$link->buttons_background_hover_color} !important;";
                        break;
                    // Botão transparente arredondado
                    case 'ghost-rounded-button':
                        $link->button_style = "background-color: transparent; border: 2px solid; color: {$link->buttons_text_color}; border-color: {$link->buttons_border_color}; border-radius: {$link->buttons_border_radius_size}px;";
                        $link->button_style_hover = "color: {$link->buttons_hover_text_color} !important; border-color: {$link->buttons_hover_border_color} !important; background-color: {$link->buttons_background_hover_color} !important;";
                        break;
                    default:
                        $link->button_style = "color: {$link->buttons_text_color};";
                        break;
                }

                $link->button_style .= NoBossUtilFonts::importNobossfontlist($link->buttons_font);
                
                $bannerItem->links_class .= "button{$count}-{$link->buttons_position} ";
                $link->button_style .= " text-transform: " . $link->buttons_text_transform . ";";
                $buttonsSize = $link->buttons_text_size;
                if(!empty($buttonsSize)){
                    $buttonsSizeEm = $buttonsSize/16;
                    $link->button_style .= " font-size: {$buttonsSize}px; font-size: {$buttonsSizeEm}em;";
                }

                $link->button_style .= isset($link->buttons_space) ? ' padding: '.implode(' ', $link->buttons_space).';' : ' padding: 0.75em 2em;';
            }
        }
    }

    // armazena a quantidade de banners ativos 
    $availableItems = count($banners);

    if($availableItems > 0){
        if($theme == "model3"){
            // manda o valor de banners ativos para o objeto js 
            $jsConfig->bannersQtd = $availableItems;
        }
    
        // Define prefixo a ser utilizado na insercao de codigos inline para CSS e JS
        $prefixCodeJsAndCss = "[module-id={$module->name}_{$module->id}]";
    
        // Obtem informacoes de codigos JS e CSS a serem inseridos
        $loadJs	 		= $params->get('load_js');
    $loadCss 		= $params->get('load_css');
    $overwritingJs	= (!empty($params->get('overwriting_js'))) ? rtrim($params->get('overwriting_js')) : '';
    $overwritingCss	= (!empty($params->get('overwriting_css'))) ? rtrim($params->get('overwriting_css')) : '';
        $iconsFamily    = "font-awesome";
    
        // Instancia objeto passando o nome da extensao com prefixo (ex: 'mod_nobossbanners')
        $assetsObject = new NoBossUtilLoadExtensionAssets($extensionName, $prefixCodeJsAndCss);
        
        // Adiciona arquivos e codigos JS (se definido para exibir)
        $assetsObject->loadJs($loadJs, array('code' => $overwritingJs));
    
        // Adiciona arquivo CSS para uma familia de fontes
        $assetsObject->loadFamilyIcons($iconsFamily);

        // Adiciona arquivos e codigos CSS (se definido para carregar)
        $assetsObject->loadCss($loadCss, array('code' => $overwritingCss));
    
        require JModuleHelper::getLayoutPath($module->module, 'theme/'.$params->get('layout', $theme));

    }
}
